Struct spl_token_bonding::accounts::InitializeSolStorageV0
source · [−]pub struct InitializeSolStorageV0 {
pub payer: Pubkey,
pub state: Pubkey,
pub sol_storage: Pubkey,
pub wrapped_sol_mint: Pubkey,
pub mint_authority: Pubkey,
pub token_program: Pubkey,
pub system_program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for InitializeSolStorageV0.
Fields
payer: Pubkeystate: Pubkeysol_storage: Pubkeywrapped_sol_mint: PubkeyCHECK: Authority, used in CPIs
token_program: Pubkeysystem_program: Pubkeyrent: PubkeyTrait Implementations
sourceimpl BorshSerialize for InitializeSolStorageV0 where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for InitializeSolStorageV0 where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for InitializeSolStorageV0
impl ToAccountMetas for InitializeSolStorageV0
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more