pub struct PreciseNumber {
    pub value: InnerUint,
}
Struct encapsulating a fixed-point number that allows for decimal calculations

Fields

value: InnerUint

Wrapper over the inner value, which is multiplied by ONE

Implementations

Create a precise number from an imprecise u128, should always succeed

Convert a precise number back to u128

Checks that two PreciseNumbers are equal within some tolerance

Checks that a number is less than another

Checks that a number is greater than another

Checks that a number is less than another

Checks that a number is greater than another

Floors a precise value to a precision of ONE

Ceiling a precise value to a precision of ONE

Performs a checked division on two precise numbers

Performs a multiplication on two precise numbers

Performs addition of two precise numbers

Subtracts the argument from self