pub struct SignedPreciseNumber {
    pub value: PreciseNumber,
    pub is_negative: bool,
}
Struct encapsulating a signed fixed-point number that allows for decimal calculations

Fields

value: PreciseNumberis_negative: bool

Implementations

Calculate the exponential of x, that is, e raised to the power x (where e is the base of the natural system of logarithms, approximately 2.71828). Note that precision can start to get inaccurate for larger numbers (> 20).