Struct spl_token_bonding::state::ProgramStateV0
source · [−]pub struct ProgramStateV0 {
pub wrapped_sol_mint: Pubkey,
pub sol_storage: Pubkey,
pub mint_authority_bump_seed: u8,
pub sol_storage_bump_seed: u8,
pub bump_seed: u8,
}Fields
wrapped_sol_mint: Pubkeysol_storage: Pubkeysol_storage_bump_seed: u8bump_seed: u8Trait Implementations
sourceimpl AccountDeserialize for ProgramStateV0
impl AccountDeserialize for ProgramStateV0
sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a Mint account into a token
Account. Read more
sourceimpl AccountSerialize for ProgramStateV0
impl AccountSerialize for ProgramStateV0
sourceimpl BorshDeserialize for ProgramStateV0 where
Pubkey: BorshDeserialize,
Pubkey: BorshDeserialize,
u8: BorshDeserialize,
u8: BorshDeserialize,
u8: BorshDeserialize,
impl BorshDeserialize for ProgramStateV0 where
Pubkey: BorshDeserialize,
Pubkey: BorshDeserialize,
u8: BorshDeserialize,
u8: BorshDeserialize,
u8: BorshDeserialize,
sourceimpl BorshSerialize for ProgramStateV0 where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
u8: BorshSerialize,
u8: BorshSerialize,
u8: BorshSerialize,
impl BorshSerialize for ProgramStateV0 where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
u8: BorshSerialize,
u8: BorshSerialize,
u8: BorshSerialize,
sourceimpl Clone for ProgramStateV0
impl Clone for ProgramStateV0
sourcefn clone(&self) -> ProgramStateV0
fn clone(&self) -> ProgramStateV0
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Default for ProgramStateV0
impl Default for ProgramStateV0
sourcefn default() -> ProgramStateV0
fn default() -> ProgramStateV0
Returns the “default value” for a type. Read more
sourceimpl Discriminator for ProgramStateV0
impl Discriminator for ProgramStateV0
fn discriminator() -> [u8; 8]
sourceimpl Owner for ProgramStateV0
impl Owner for ProgramStateV0