pub struct TokenBondingV0 {
Show 31 fields pub base_mint: Pubkey, pub target_mint: Pubkey, pub general_authority: Option<Pubkey>, pub reserve_authority: Option<Pubkey>, pub curve_authority: Option<Pubkey>, pub base_storage: Pubkey, pub buy_base_royalties: Pubkey, pub buy_target_royalties: Pubkey, pub sell_base_royalties: Pubkey, pub sell_target_royalties: Pubkey, pub buy_base_royalty_percentage: u32, pub buy_target_royalty_percentage: u32, pub sell_base_royalty_percentage: u32, pub sell_target_royalty_percentage: u32, pub curve: Pubkey, pub mint_cap: Option<u64>, pub purchase_cap: Option<u64>, pub go_live_unix_time: i64, pub freeze_buy_unix_time: Option<i64>, pub created_at_unix_time: i64, pub buy_frozen: bool, pub sell_frozen: bool, pub index: u16, pub bump_seed: u8, pub base_storage_bump_seed: u8, pub target_mint_authority_bump_seed: u8, pub base_storage_authority_bump_seed: Option<u8>, pub reserve_balance_from_bonding: u64, pub supply_from_bonding: u64, pub ignore_external_reserve_changes: bool, pub ignore_external_supply_changes: bool,
}

Fields

base_mint: Pubkeytarget_mint: Pubkeygeneral_authority: Option<Pubkey>reserve_authority: Option<Pubkey>curve_authority: Option<Pubkey>base_storage: Pubkeybuy_base_royalties: Pubkeybuy_target_royalties: Pubkeysell_base_royalties: Pubkeysell_target_royalties: Pubkeybuy_base_royalty_percentage: u32

Percentage of purchases that go to royalties Percentage Value is (founder_reward_percentage / u32.MAX_VALUE) * 100

buy_target_royalty_percentage: u32sell_base_royalty_percentage: u32sell_target_royalty_percentage: u32curve: Pubkey

The bonding curve to use

mint_cap: Option<u64>purchase_cap: Option<u64>go_live_unix_time: i64freeze_buy_unix_time: Option<i64>created_at_unix_time: i64buy_frozen: boolsell_frozen: boolindex: u16bump_seed: u8base_storage_bump_seed: u8target_mint_authority_bump_seed: u8base_storage_authority_bump_seed: Option<u8>reserve_balance_from_bonding: u64supply_from_bonding: u64ignore_external_reserve_changes: bool

Whether or not to ignore changes to base storage and target supply outside of the curve

ignore_external_supply_changes: bool