pub struct SignedPreciseNumber {
pub value: PreciseNumber,
pub is_negative: bool,
}Expand description
Struct encapsulating a signed fixed-point number that allows for decimal calculations
Fields
value: PreciseNumberis_negative: boolImplementations
sourceimpl SignedPreciseNumber
impl SignedPreciseNumber
pub fn negate(&self) -> SignedPreciseNumber
pub fn checked_mul(&self, rhs: &Self) -> Option<SignedPreciseNumber>
pub fn checked_div(&self, rhs: &Self) -> Option<SignedPreciseNumber>
pub fn checked_add(&self, rhs: &Self) -> Option<SignedPreciseNumber>
pub fn checked_sub(&self, rhs: &Self) -> Option<SignedPreciseNumber>
pub fn floor(&self) -> Option<SignedPreciseNumber>
sourcepub fn exp(&self) -> Option<PreciseNumber>
pub fn exp(&self) -> Option<PreciseNumber>
Calculate the exponential of x, that is, e raised to the power x
(where e is the base of the natural system of logarithms, approximately 2.71828).
Note that precision can start to get inaccurate for larger numbers (> 20).
pub fn print(&self)